@@ -3,7 +3,7 @@ from typing import List, Union
 
 from nwon_baseline.typings import AnyDict
 
-from nwon_django_toolbox.nwon_django_settings import NWONDjangoSettings
+from nwon_django_toolbox.settings import NWON_DJANGO_SETTINGS
 from nwon_django_toolbox.typings.error_response import ErrorResponse
 
 
@@ -18,5 +18,5 @@ def get_error_response(
         message=http_code_to_message[status_code],
         details=details,
         status_code=status_code,
-        api_docs=NWONDjangoSettings.api_docs_url,
+        api_docs=NWON_DJANGO_SETTINGS.api_docs_url,
     ).dict()
