@@ -5,18 +5,28 @@ from nwon_django_toolbox.typings.permission_test_expectation import (
     LoginFunction,
     PermissionTestExpectation,
 )
+from nwon_django_toolbox.typings.permissions import (
+    GroupPermissionMapping,
+    PermissionConfiguration,
+    PermissionConfigurationForGroup,
+    PermissionPrefix,
+)
 from nwon_django_toolbox.typings.pydantic_base_django import PydanticBaseDjango
 from nwon_django_toolbox.typings.request_body_format import RequestBodyFormat
-from nwon_django_toolbox.typings.test_fixture import TestFixture
+from nwon_django_toolbox.typings.test_fixture import Fixture
 
 __all__ = [
     "ErrorResponse",
     "CeleryFolder",
     "CeleryReturn",
-    "TestFixture",
+    "Fixture",
     "DjangoReadyEnum",
     "PydanticBaseDjango",
     "RequestBodyFormat",
     "PermissionTestExpectation",
     "LoginFunction",
+    "GroupPermissionMapping",
+    "PermissionConfiguration",
+    "PermissionConfigurationForGroup",
+    "PermissionPrefix",
 ]
