@@ -1,7 +1,7 @@
 from nwon_django_toolbox.typings.pydantic_base_django import PydanticBaseDjango
 
 
-class TestFixture(PydanticBaseDjango):
+class Fixture(PydanticBaseDjango):
     path: str
     model_name: str
     preserve_password: bool
